Get the HTTPS URL for the git remote of a repo at code.usgs.gov
Source:R/use_project_usgs.R
get_usgs_gitlab_url.RdGet the HTTPS URL for the git remote of a repo at code.usgs.gov
R/use_project_usgs.R
get_usgs_gitlab_url.RdGet the HTTPS URL for the git remote of a repo at code.usgs.gov